@@ -2,7 +2,7 @@ import os
 import platform
 
 proj_dir_windows = "X:"
-proj_dir_macos = "smb://ams-fileserver/x"
+proj_dir_macos = "/Volumes/ams-fileserver/"
 
 
 def get_latest_proj():
