@@ -26,12 +26,25 @@ def create_new_project(session):
         sorted([p["name"] for p in projects if "invoice" not in p["name"]]),
         "Select the team:",
     )
-    print(option)
+
     clearConsole()
     num = get_latest_proj()
     team = [t for t in projects if option.lower() == t["name"].lower()][0]
     print(f"💁‍♂️ Making a new project for {team['name']}")
 
+    mgmt = []
+    for m in team["managers"]:
+        if "Annelies" not in m["user"]["username"]:
+            mgmt.append(m["user"])
+
+    project_team = []
+
+    for a in team["allocations"]:
+        resource = a["resource"]
+        if isinstance(resource, session.types['User']):
+            user = resource
+            project_team.append(user)
+
     dest_folder = None
 
     for child in team["children"]:
@@ -50,7 +63,7 @@ def create_new_project(session):
         else:
             print("didnt get ya fully")
             continue
-
+    
     while True:
         projname = input("Enter project letter code (3 characters):")
         if len(projname) == 3:
@@ -66,7 +79,6 @@ def create_new_project(session):
             num_int = int(input("Enter amount of INT shots:\n"))
         except ValueError:
             print("Sorry, I didn't understand that? Did you type a number?")
-            # better try again... Return to the start of the loop
             continue
         else:
             print(f"Number of INT:{num_int}")
@@ -102,7 +114,6 @@ def create_new_project(session):
     task_templates = team["project_schema"]["task_templates"]
 
     for template in task_templates:
-        # print(template["name"])
         if template["name"] == "Annelies_Template":
             annelies_template = template
         if template["name"] == "Image_Template":
@@ -110,10 +121,8 @@ def create_new_project(session):
         if template["name"] == "PM_Template":
             production_template = template
 
-    pm_choice, index = pick(["Hanne", "Nele", "Pieter"], "Select project manager")
-    project_manager = [i for i in users if pm_choice.lower() in i["username"].lower()][
-        0
-    ]
+    pm_choice, index = pick([m["username"] for m in mgmt], "Select project manager")
+    project_manager = mgmt[index]
 
     for task_type in [t["task_type"] for t in production_template["items"]]:
         task = session.create("Task",
@@ -142,11 +151,15 @@ def create_new_project(session):
     if num_int > 0:
         int_folder = session.create("Folder",
                                     {"name": f"{num}_INT", "parent": proj})
-        ia, index = pick(
-            ["Tom", "Ellen", "Dainius", "Siarhei", "Lowie", "Austris"],
-            "Select interior artist:",
-        )
-        int_artist = [i for i in users if ia.lower() in i["username"].lower()][0]
+
+        if len(project_team) > 1:    
+            ia, index = pick(
+                [u["username"] for u in project_team],
+                "Select interior artist:",
+            )
+            int_artist = [i for i in users if ia.lower() in i["username"].lower()][0]
+        else:
+            int_artist = project_team[0]
 
         for i in range(num_int):
             int_shot_name = f"{num}_INT_{chr(ord('@')+i+1)}"
@@ -165,12 +178,16 @@ def create_new_project(session):
 
     if num_ext > 0:
         ext_folder = session.create("Folder", {"name": f"{num}_EXT", "parent": proj})
-        exterior_artist, index = pick(
-            ["Tom", "Robin", "Dainius", "Siarhei", "Lowie"], "Select exterior artist:"
-        )
-        ext_artist = [
-            i for i in users if exterior_artist.lower() in i["username"].lower()
-        ][0]
+
+        if len(project_team) > 1:
+
+            exterior_artist, index = pick([u["username"] for u in project_team], "Select exterior artist:")
+            ext_artist = [
+                i for i in users if exterior_artist.lower() in i["username"].lower()
+            ][0]
+        else:
+            ext_artist = project_team[0]
+
         for i in range(num_ext):
             ext_shot_name = f"{num}_EXT_{chr(ord('@')+i+1)}"
             ext_shot = session.create(
@@ -194,7 +211,6 @@ def create_new_project(session):
     print(f"--- creating objects for {project_name} on ftrack")
     print(f"--- creating outlook folder for {project_name}")
     print(f"--- creating directory for {project_name} on X:/")
-    # create_project_on_fileserver(project_name)
     print(f"-- {num_int} INT tasks for {ia}") if num_int > 0 else None
     print(f"-- {num_ext} EXT tasks for {exterior_artist}") if num_ext > 0 else None
     print("--- creating photography tasks") if drone else None
